@@ -1,11 +1,13 @@
 import os
 import sys
-
 import requests
 
+from collections import OrderedDict
+
 import conans
 from conans import __version__ as client_version, tools
 from conans.client.cmd.create import create
+from conans.client.plugin_manager import PluginManager
 from conans.client.recorder.action_recorder import ActionRecorder
 from conans.client.client_cache import ClientCache
 from conans.client.conf import MIN_SERVER_COMPATIBLE_VERSION, ConanClientConfigParser
@@ -89,7 +91,6 @@ def api_method(f):
             raise
         finally:
             os.chdir(curdir)
-
     return wrapper
 
 
@@ -138,7 +139,7 @@ class ConanAPIV1(object):
 
     @staticmethod
     def instance_remote_manager(requester, client_cache, user_io, _client_version,
-                                min_server_compatible_version):
+                                min_server_compatible_version, plugin_manager):
 
         # Verify client version against remotes
         version_checker_req = VersionCheckerRequester(requester, _client_version,
@@ -154,7 +155,7 @@ class ConanAPIV1(object):
         # Wraps RestApiClient to add authentication support (same interface)
         auth_manager = ConanApiAuthManager(rest_api_client, user_io, localdb)
         # Handle remote connections
-        remote_manager = RemoteManager(client_cache, auth_manager, user_io.out)
+        remote_manager = RemoteManager(client_cache, auth_manager, user_io.out, plugin_manager)
         return localdb, rest_api_client, remote_manager
 
     @staticmethod
@@ -189,13 +190,18 @@ class ConanAPIV1(object):
             # Adjust CONAN_LOGGING_LEVEL with the env readed
             conans.util.log.logger = configure_logger()
 
+            # Create Plugin Manager
+            plugin_manager = PluginManager(client_cache.plugins_path,
+                                           get_env("CONAN_PLUGINS", list()), user_io.out)
+
             # Get the new command instance after migrations have been done
             requester = get_basic_requester(client_cache)
             _, _, remote_manager = ConanAPIV1.instance_remote_manager(
                 requester,
                 client_cache, user_io,
                 Version(client_version),
-                Version(MIN_SERVER_COMPATIBLE_VERSION))
+                Version(MIN_SERVER_COMPATIBLE_VERSION),
+                plugin_manager)
 
             # Adjust global tool variables
             set_global_instances(out, requester)
@@ -204,11 +210,12 @@ class ConanAPIV1(object):
             if interactive is None:
                 interactive = not get_env("CONAN_NON_INTERACTIVE", False)
             conan = ConanAPIV1(client_cache, user_io, get_conan_runner(), remote_manager,
-                               interactive=interactive)
+                               plugin_manager, interactive=interactive)
 
         return conan, client_cache, user_io
 
-    def __init__(self, client_cache, user_io, runner, remote_manager, interactive=True):
+    def __init__(self, client_cache, user_io, runner, remote_manager, plugin_manager,
+                 interactive=True):
         assert isinstance(user_io, UserIO)
         assert isinstance(client_cache, ClientCache)
         self._client_cache = client_cache
@@ -219,18 +226,20 @@ class ConanAPIV1(object):
         if not interactive:
             self._user_io.disable_input()
 
-        self._proxy = ConanProxy(client_cache, self._user_io.out, remote_manager, registry=self._registry)
+        self._proxy = ConanProxy(client_cache, self._user_io.out, remote_manager,
+                                 registry=self._registry)
         resolver = RangeResolver(self._user_io.out, client_cache, self._proxy)
         python_requires = ConanPythonRequire(self._proxy, resolver)
         self._loader = ConanFileLoader(self._runner, self._user_io.out, python_requires)
         self._graph_manager = GraphManager(self._user_io.out, self._client_cache, self._registry,
                                            self._remote_manager, self._loader, self._proxy, resolver)
+        self._plugin_manager = plugin_manager
 
     def _init_manager(self, action_recorder):
         """Every api call gets a new recorder and new manager"""
         return ConanManager(self._client_cache, self._user_io, self._runner,
                             self._remote_manager, action_recorder, self._registry,
-                            self._graph_manager)
+                            self._graph_manager, self._plugin_manager)
 
     @api_method
     def new(self, name, header=False, pure_c=False, test=False, exports_sources=False, bare=False,
@@ -257,6 +266,34 @@ class ConanAPIV1(object):
         for f in sorted(files):
             self._user_io.out.success("File saved: %s" % f)
 
+    @api_method
+    def inspect(self, path, attributes, remote_name=None):
+        try:
+            reference = ConanFileReference.loads(path)
+        except ConanException:
+            reference = None
+            cwd = get_cwd()
+            conanfile_path = _get_conanfile_path(path, cwd, py=True)
+        else:
+            update = True if remote_name else False
+            result = self._proxy.get_recipe(reference, update, update, remote_name,
+                                            ActionRecorder())
+            conanfile_path, _, _, reference = result
+        conanfile = self._loader.load_basic(conanfile_path, self._user_io.out)
+
+        result = OrderedDict()
+        if not attributes:
+            attributes = ['name', 'version', 'url', 'license', 'author', 'description',
+                          'generators', 'exports', 'exports_sources', 'short_paths',
+                          'apply_env',  'build_policy']
+        for attribute in attributes:
+            try:
+                attr = getattr(conanfile, attribute)
+                result[attribute] = attr
+            except AttributeError as e:
+                raise ConanException(str(e))
+        return result
+
     @api_method
     def test(self, path, reference, profile_name=None, settings=None, options=None, env=None,
              remote_name=None, update=False, build_modes=None, cwd=None, test_build_folder=None):
@@ -301,14 +338,15 @@ class ConanAPIV1(object):
             recorder = ActionRecorder()
             conanfile_path = _get_conanfile_path(conanfile_path, cwd, py=True)
 
-            reference, conanfile = self._loader.load_export(conanfile_path, name, version, user, channel)
+            reference, conanfile = self._loader.load_export(conanfile_path, name, version, user,
+                                                            channel)
 
             # Make sure keep_source is set for keep_build
             keep_source = keep_source or keep_build
             # Forcing an export!
             if not not_export:
                 cmd_export(conanfile_path, conanfile, reference, keep_source, self._user_io.out,
-                           self._client_cache)
+                           self._client_cache, self._plugin_manager)
 
             if build_modes is None:  # Not specified, force build the tested library
                 build_modes = [conanfile.name]
@@ -351,7 +389,8 @@ class ConanAPIV1(object):
 
         if package_folder:
             if build_folder or source_folder:
-                raise ConanException("package folder definition incompatible with build and source folders")
+                raise ConanException("package folder definition incompatible with build "
+                                     "and source folders")
             package_folder = _make_abs_path(package_folder, cwd)
 
         build_folder = _make_abs_path(build_folder, cwd)
@@ -373,7 +412,8 @@ class ConanAPIV1(object):
             profile = read_conaninfo_profile(install_folder)
 
         reference, conanfile = self._loader.load_export(conanfile_path, name, version, user, channel)
-        cmd_export(conanfile_path, conanfile, reference, False, self._user_io.out, self._client_cache)
+        cmd_export(conanfile_path, conanfile, reference, False, self._user_io.out,
+                   self._client_cache, self._plugin_manager)
 
         recorder = ActionRecorder()
         manager = self._init_manager(recorder)
@@ -389,7 +429,8 @@ class ConanAPIV1(object):
         conan_ref = ConanFileReference.loads(reference)
         recorder = ActionRecorder()
         download(conan_ref, package, remote_name, recipe, self._registry, self._remote_manager,
-                 self._client_cache, self._user_io.out, recorder, self._loader)
+                 self._client_cache, self._user_io.out, recorder, self._loader,
+                 self._plugin_manager)
 
     @api_method
     def install_reference(self, reference, settings=None, options=None, env=None,
@@ -495,6 +536,10 @@ class ConanAPIV1(object):
 
     @api_method
     def config_install(self, item, verify_ssl, config_type=None, args=None):
+        # _make_abs_path, but could be not a path at all
+        if item is not None and os.path.exists(item) and not os.path.isabs(item):
+            item = os.path.abspath(item)
+
         from conans.client.conf.config_installer import configuration_install
         return configuration_install(item, self._client_cache, self._user_io.out, verify_ssl, config_type, args)
 
@@ -624,7 +669,8 @@ class ConanAPIV1(object):
     def export(self, path, name, version, user, channel, keep_source=False, cwd=None):
         conanfile_path = _get_conanfile_path(path, cwd, py=True)
         reference, conanfile = self._loader.load_export(conanfile_path, name, version, user, channel)
-        cmd_export(conanfile_path, conanfile, reference, keep_source, self._user_io.out, self._client_cache)
+        cmd_export(conanfile_path, conanfile, reference, keep_source, self._user_io.out,
+                   self._client_cache, self._plugin_manager)
 
     @api_method
     def remove(self, pattern, query=None, packages=None, builds=None, src=False, force=False,
@@ -716,27 +762,17 @@ class ConanAPIV1(object):
         return recorder.get_info()
 
     @api_method
-    def upload(self, pattern, package=None, remote_name=None,
-               all_packages=False, force=False, confirm=False, retry=2,
-               retry_wait=5, skip_upload=False, integrity_check=False,
-               no_overwrite=None, query=None):
+    def upload(self, pattern, package=None, remote_name=None, all_packages=False, confirm=False,
+               retry=2, retry_wait=5, integrity_check=False, policy=None, query=None):
         """ Uploads a package recipe and the generated binary packages to a specified remote
         """
 
         recorder = UploadRecorder()
-
-        if force and no_overwrite:
-            exc = ConanException("'no_overwrite' argument cannot be used together with 'force'")
-            recorder.error = True
-            exc.info = recorder.get_info()
-            raise exc
-
         uploader = CmdUpload(self._client_cache, self._user_io, self._remote_manager,
-                             self._registry, self._loader)
+                             self._registry, self._loader, self._plugin_manager)
         try:
-            uploader.upload(recorder, pattern, package, all_packages, force, confirm, retry,
-                            retry_wait, skip_upload, integrity_check, no_overwrite, remote_name,
-                            query=query)
+            uploader.upload(recorder, pattern, package, all_packages, confirm, retry,
+                            retry_wait, integrity_check, policy, remote_name, query=query)
             return recorder.get_info()
         except ConanException as exc:
             recorder.error = True
