@@ -26,7 +26,7 @@ class ConanManager(object):
     business logic
     """
     def __init__(self, client_cache, user_io, runner, remote_manager,
-                 recorder, registry, graph_manager):
+                 recorder, registry, graph_manager, plugin_manager):
         assert isinstance(user_io, UserIO)
         assert isinstance(client_cache, ClientCache)
         self._client_cache = client_cache
@@ -36,6 +36,7 @@ class ConanManager(object):
         self._recorder = recorder
         self._registry = registry
         self._graph_manager = graph_manager
+        self._plugin_manager = plugin_manager
 
     def export_pkg(self, reference, source_folder, build_folder, package_folder, install_folder, profile, force):
 
@@ -70,10 +71,11 @@ class ConanManager(object):
         package_output = ScopedOutput(str(reference), self._user_io.out)
         if package_folder:
             packager.export_pkg(conanfile, pkg_id, package_folder, dest_package_folder,
-                                package_output)
+                                package_output, self._plugin_manager, conan_file_path, reference)
         else:
             packager.create_package(conanfile, pkg_id, source_folder, build_folder,
-                                    dest_package_folder, install_folder, package_output, local=True)
+                                    dest_package_folder, install_folder, package_output,
+                                    self._plugin_manager, conan_file_path, reference, local=True)
 
     def install_workspace(self, profile, workspace, remote_name, build_modes, update):
         references = [ConanFileReference(v, "root", "project", "develop") for v in workspace.root]
@@ -85,7 +87,8 @@ class ConanManager(object):
         print_graph(deps_graph, self._user_io.out)
 
         installer = ConanInstaller(self._client_cache, output, self._remote_manager,
-                                   self._registry, recorder=self._recorder, workspace=workspace)
+                                   self._registry, recorder=self._recorder, workspace=workspace,
+                                   plugin_manager=self._plugin_manager)
         installer.install(deps_graph, keep_build=False)
         workspace.generate()
 
@@ -114,6 +117,8 @@ class ConanManager(object):
             generators = set(generators) if generators else set()
             generators.add("txt")  # Add txt generator by default
 
+        self._user_io.out.info("Configuration:")
+        self._user_io.out.writeln(profile.dumps())
         result = self._graph_manager.load_graph(reference, create_reference, profile,
                                                 build_modes, False, update, remote_name, self._recorder,
                                                 None)
@@ -137,7 +142,8 @@ class ConanManager(object):
             pass
 
         installer = ConanInstaller(self._client_cache, output, self._remote_manager,
-                                   self._registry, recorder=self._recorder, workspace=None)
+                                   self._registry, recorder=self._recorder, workspace=None,
+                                   plugin_manager=self._plugin_manager)
         installer.install(deps_graph, keep_build)
 
         if manifest_folder:
@@ -191,7 +197,8 @@ class ConanManager(object):
         if conanfile_folder != source_folder:
             output.info("Executing exports to: %s" % source_folder)
             _execute_export(conanfile_path, conanfile, source_folder, source_folder, output)
-        config_source_local(source_folder, conanfile, conanfile_folder, output)
+        config_source_local(source_folder, conanfile, conanfile_folder, output, conanfile_path,
+                            self._plugin_manager)
 
     def imports(self, conan_file_path, dest_folder, info_folder):
         """
@@ -212,10 +219,11 @@ class ConanManager(object):
             raise ConanException("Cannot 'conan package' to the build folder. "
                                  "--build-folder and package folder can't be the same")
         output = ScopedOutput("PROJECT", self._user_io.out)
-        conanfile = self._graph_manager.load_consumer_conanfile(conanfile_path, install_folder, output,
-                                                                deps_info_required=True)
+        conanfile = self._graph_manager.load_consumer_conanfile(conanfile_path, install_folder,
+                                                                output, deps_info_required=True)
         packager.create_package(conanfile, None, source_folder, build_folder, package_folder,
-                                install_folder, output, local=True, copy_info=True)
+                                install_folder, output, self._plugin_manager, conanfile_path, None,
+                                local=True, copy_info=True)
 
     def build(self, conanfile_path, source_folder, build_folder, package_folder, install_folder,
               test=False, should_configure=True, should_build=True, should_install=True,
@@ -257,10 +265,14 @@ class ConanManager(object):
             conan_file.source_folder = source_folder
             conan_file.package_folder = package_folder
             conan_file.install_folder = install_folder
+            self._plugin_manager.execute("pre_build", conanfile=conan_file,
+                                         conanfile_path=conanfile_path)
             with get_env_context_manager(conan_file):
                 output.highlight("Running build()")
                 with conanfile_exception_formatter(str(conan_file), "build"):
                     conan_file.build()
+                self._plugin_manager.execute("post_build", conanfile=conan_file,
+                                             conanfile_path=conanfile_path)
                 if test:
                     output.highlight("Running test()")
                     with conanfile_exception_formatter(str(conan_file), "test"):
