@@ -4,15 +4,15 @@ import time
 from six.moves.urllib.parse import urlparse, urljoin, urlsplit, parse_qs
 
 from conans.client.remote_manager import check_compressed_files
-from conans.client.rest.differ import diff_snapshots
 from conans.client.rest.rest_client_common import RestCommonMethods
 from conans.client.rest.uploader_downloader import Downloader, Uploader
 from conans.errors import NotFoundException, ConanException
 from conans.model.info import ConanInfo
 from conans.model.manifest import FileTreeManifest
+from conans.model.ref import PackageReference
 from conans.paths import CONAN_MANIFEST, CONANINFO, EXPORT_SOURCES_TGZ_NAME, EXPORT_TGZ_NAME, \
     PACKAGE_TGZ_NAME
-from conans.util.files import decode_text, md5sum
+from conans.util.files import decode_text
 from conans.util.log import logger
 
 
@@ -31,20 +31,23 @@ class RestV1Methods(RestCommonMethods):
     def remote_api_url(self):
         return "%s/v1" % self.remote_url.rstrip("/")
 
-    def _download_files(self, file_urls):
+    def _download_files(self, file_urls, quiet=False):
         """
         :param: file_urls is a dict with {filename: url}
 
         Its a generator, so it yields elements for memory performance
         """
-        downloader = Downloader(self.requester, self._output, self.verify_ssl)
+        output = self._output if not quiet else None
+        downloader = Downloader(self.requester, output, self.verify_ssl)
         # Take advantage of filenames ordering, so that conan_package.tgz and conan_export.tgz
         # can be < conanfile, conaninfo, and sent always the last, so smaller files go first
         for filename, resource_url in sorted(file_urls.items(), reverse=True):
-            self._output.writeln("Downloading %s" % filename)
+            if output:
+                output.writeln("Downloading %s" % filename)
             auth, _ = self._file_server_capabilities(resource_url)
             contents = downloader.download(resource_url, auth=auth)
-            self._output.writeln("")
+            if output:
+                output.writeln("")
             yield os.path.normpath(filename), contents
 
     def _file_server_capabilities(self, resource_url):
@@ -63,11 +66,11 @@ class RestV1Methods(RestCommonMethods):
         """Gets a FileTreeManifest from conans"""
 
         # Obtain the URLs
-        url = "%s/conans/%s/digest" % (self.remote_api_url, "/".join(conan_reference))
+        url = "%s/digest" % self._recipe_url(conan_reference)
         urls = self._get_file_to_url_dict(url)
 
         # Get the digest
-        contents = self._download_files(urls)
+        contents = self._download_files(urls, quiet=True)
         # Unroll generator and decode shas (plain text)
         contents = {key: decode_text(value) for key, value in dict(contents).items()}
         return FileTreeManifest.loads(contents[CONAN_MANIFEST])
@@ -76,13 +79,11 @@ class RestV1Methods(RestCommonMethods):
         """Gets a FileTreeManifest from a package"""
 
         # Obtain the URLs
-        url = "%s/conans/%s/packages/%s/digest" % (self.remote_api_url,
-                                                   "/".join(package_reference.conan),
-                                                   package_reference.package_id)
+        url = "%s/digest" % self._package_url(package_reference)
         urls = self._get_file_to_url_dict(url)
 
         # Get the digest
-        contents = self._download_files(urls)
+        contents = self._download_files(urls, quiet=True)
         # Unroll generator and decode shas (plain text)
         contents = {key: decode_text(value) for key, value in dict(contents).items()}
         return FileTreeManifest.loads(contents[CONAN_MANIFEST])
@@ -90,9 +91,7 @@ class RestV1Methods(RestCommonMethods):
     def get_package_info(self, package_reference):
         """Gets a ConanInfo file from a package"""
 
-        url = "%s/conans/%s/packages/%s/download_urls" % (self.remote_api_url,
-                                                          "/".join(package_reference.conan),
-                                                          package_reference.package_id)
+        url = "%s/download_urls" % self._package_url(package_reference)
         urls = self._get_file_to_url_dict(url)
         if not urls:
             raise NotFoundException("Package not found!")
@@ -112,6 +111,25 @@ class RestV1Methods(RestCommonMethods):
         urls = self.get_json(url, data=data)
         return {filepath: complete_url(self.remote_url, url) for filepath, url in urls.items()}
 
+    def _upload_recipe(self, conan_reference, files_to_upload, retry, retry_wait):
+        # Get the upload urls and then upload files
+        url = "%s/upload_urls" % self._recipe_url(conan_reference)
+        filesizes = {filename.replace("\\", "/"): os.stat(abs_path).st_size
+                     for filename, abs_path in files_to_upload.items()}
+        urls = self._get_file_to_url_dict(url, data=filesizes)
+        self._upload_files(urls, files_to_upload, self._output, retry, retry_wait)
+
+    def _upload_package(self, package_reference, files_to_upload, retry, retry_wait):
+        # Get the upload urls and then upload files
+        url = "%s/upload_urls" % self._package_url(package_reference)
+        filesizes = {filename: os.stat(abs_path).st_size for filename,
+                     abs_path in files_to_upload.items()}
+        self._output.rewrite_line("Requesting upload urls...")
+        urls = self._get_file_to_url_dict(url, data=filesizes)
+        self._output.rewrite_line("Requesting upload urls...Done!")
+        self._output.writeln("")
+        self._upload_files(urls, files_to_upload, self._output, retry, retry_wait)
+
     def _upload_files(self, file_urls, files, output, retry, retry_wait):
         t1 = time.time()
         failed = []
@@ -123,7 +141,8 @@ class RestV1Methods(RestCommonMethods):
             auth, dedup = self._file_server_capabilities(resource_url)
             try:
                 response = uploader.upload(resource_url, files[filename], auth=auth, dedup=dedup,
-                                           retry=retry, retry_wait=retry_wait, headers=self._put_headers)
+                                           retry=retry, retry_wait=retry_wait,
+                                           headers=self._put_headers)
                 output.writeln("")
                 if not response.ok:
                     output.error("\nError uploading file: %s, '%s'" % (filename, response.content))
@@ -180,7 +199,7 @@ class RestV1Methods(RestCommonMethods):
     def _get_recipe_urls(self, conan_reference):
         """Gets a dict of filename:contents from conans"""
         # Get the conanfile snapshot first
-        url = "%s/conans/%s/download_urls" % (self.remote_api_url, "/".join(conan_reference))
+        url = "%s/download_urls" % self._recipe_url(conan_reference)
         urls = self._get_file_to_url_dict(url)
         return urls
 
@@ -192,126 +211,21 @@ class RestV1Methods(RestCommonMethods):
 
     def _get_package_urls(self, package_reference):
         """Gets a dict of filename:contents from package"""
-        url = "%s/conans/%s/packages/%s/download_urls" % (self.remote_api_url,
-                                                          "/".join(package_reference.conan),
-                                                          package_reference.package_id)
+        url = "%s/download_urls" % self._package_url(package_reference)
         urls = self._get_file_to_url_dict(url)
         if not urls:
             raise NotFoundException("Package not found!")
 
         return urls
 
-    def upload_recipe(self, conan_reference, the_files, retry, retry_wait, ignore_deleted_file,
-                      no_overwrite):
-        """
-        the_files: dict with relative_path: content
-        """
-        self.check_credentials()
-
-        # Get the remote snapshot
-        remote_snapshot = self._get_conan_snapshot(conan_reference)
-        local_snapshot = {filename: md5sum(abs_path) for filename, abs_path in the_files.items()}
-
-        # Get the diff
-        new, modified, deleted = diff_snapshots(local_snapshot, remote_snapshot)
-        if ignore_deleted_file and ignore_deleted_file in deleted:
-            deleted.remove(ignore_deleted_file)
-
-        if not new and not deleted and modified in (["conanmanifest.txt"], []):
-            return False, conan_reference
-
-        if no_overwrite and remote_snapshot:
-            if no_overwrite in ("all", "recipe"):
-                raise ConanException("Local recipe is different from the remote recipe. "
-                                     "Forbidden overwrite")
-        files_to_upload = {filename.replace("\\", "/"): the_files[filename]
-                           for filename in new + modified}
-
-        if files_to_upload:
-            # Get the upload urls
-            url = "%s/conans/%s/upload_urls" % (self.remote_api_url, "/".join(conan_reference))
-            filesizes = {filename.replace("\\", "/"): os.stat(abs_path).st_size
-                         for filename, abs_path in files_to_upload.items()}
-            urls = self._get_file_to_url_dict(url, data=filesizes)
-            self._upload_files(urls, files_to_upload, self._output, retry, retry_wait)
-        if deleted:
-            self._remove_conanfile_files(conan_reference, deleted)
-
-        return (files_to_upload or deleted), conan_reference
-
-    def upload_package(self, package_reference, the_files, retry, retry_wait, no_overwrite):
-        """
-        basedir: Base directory with the files to upload (for read the files in disk)
-        relative_files: relative paths to upload
-        """
-        self.check_credentials()
-
-        t1 = time.time()
-        # Get the remote snapshot
-        remote_snapshot = self._get_package_snapshot(package_reference)
-        local_snapshot = {filename: md5sum(abs_path) for filename, abs_path in the_files.items()}
-
-        # Get the diff
-        new, modified, deleted = diff_snapshots(local_snapshot, remote_snapshot)
-        if not new and not deleted and modified in (["conanmanifest.txt"], []):
-            return False
-
-        if no_overwrite and remote_snapshot:
-            if no_overwrite == "all":
-                raise ConanException("Local package is different from the remote package. "
-                                     "Forbidden overwrite")
-
-        files_to_upload = {filename: the_files[filename] for filename in new + modified}
-        if files_to_upload:        # Obtain upload urls
-            url = "%s/conans/%s/packages/%s/upload_urls" % (self.remote_api_url,
-                                                            "/".join(package_reference.conan),
-                                                            package_reference.package_id)
-            filesizes = {filename: os.stat(abs_path).st_size for filename,
-                         abs_path in files_to_upload.items()}
-            self._output.rewrite_line("Requesting upload permissions...")
-            urls = self._get_file_to_url_dict(url, data=filesizes)
-            self._output.rewrite_line("Requesting upload permissions...Done!")
-            self._output.writeln("")
-            self._upload_files(urls, files_to_upload, self._output, retry, retry_wait)
-        if deleted:
-            raise Exception("This shouldn't be happening, deleted files "
-                            "in local package present in remote: %s.\n Please, report it at "
-                            "https://github.com/conan-io/conan/issues " % str(deleted))
-
-        logger.debug("====> Time rest client upload_package: %f" % (time.time() - t1))
-        return files_to_upload or deleted
-
-    def _get_conan_snapshot(self, reference):
-        url = "%s/conans/%s" % (self.remote_api_url, '/'.join(reference))
-        try:
-            snapshot = self.get_json(url)
-        except NotFoundException:
-            snapshot = {}
-        norm_snapshot = {os.path.normpath(filename): the_md5
-                         for filename, the_md5 in snapshot.items()}
-        return norm_snapshot
-
-    def _get_package_snapshot(self, package_reference):
-        url = "%s/conans/%s/packages/%s" % (self.remote_api_url,
-                                            "/".join(package_reference.conan),
-                                            package_reference.package_id)
-        try:
-            snapshot = self.get_json(url)
-        except NotFoundException:
-            snapshot = {}
-        norm_snapshot = {os.path.normpath(filename): the_md5
-                         for filename, the_md5 in snapshot.items()}
-        return norm_snapshot
-
     def get_path(self, conan_reference, package_id, path):
         """Gets a file content or a directory list"""
 
+        tmp = "%s/download_urls"
         if not package_id:
-            url = "%s/conans/%s/download_urls" % (self.remote_api_url, "/".join(conan_reference))
+            url = tmp % self._recipe_url(conan_reference)
         else:
-            url = "%s/conans/%s/packages/%s/download_urls" % (self.remote_api_url,
-                                                              "/".join(conan_reference),
-                                                              package_id)
+            url = tmp % self._package_url(PackageReference(conan_reference, package_id))
         try:
             urls = self._get_file_to_url_dict(url)
         except NotFoundException:
@@ -345,3 +259,30 @@ class RestV1Methods(RestCommonMethods):
             content = downloader.download(urls[path], auth=auth)
 
             return decode_text(content)
+
+    def _get_snapshot(self, url):
+        try:
+            snapshot = self.get_json(url)
+            snapshot = {os.path.normpath(filename): the_md5
+                        for filename, the_md5 in snapshot.items()}
+        except NotFoundException:
+            snapshot = []
+        return snapshot
+
+    def _get_recipe_snapshot(self, reference):
+        url = self._recipe_url(reference)
+        snap = self._get_snapshot(url)
+        return snap, reference.copy_without_revision()
+
+    def _get_package_snapshot(self, package_reference):
+        url = self._package_url(package_reference)
+        snap = self._get_snapshot(url)
+        return snap, package_reference
+
+    def _recipe_url(self, conan_reference):
+        return "%s/conans/%s" % (self.remote_api_url, "/".join(conan_reference))
+
+    def _package_url(self, p_reference):
+        url = self._recipe_url(p_reference.conan)
+        url += "/packages/%s" % p_reference.package_id
+        return url
