@@ -38,12 +38,10 @@ class Pkg(ConanFile):
             self.client.run("export . lasote/stable")
             expected_output = textwrap.dedent(
                 """\
-                WARN: Conanfile doesn't have 'url'.
-                It is recommended to add it as attribute
-                WARN: Conanfile doesn't have 'license'.
-                It is recommended to add it as attribute
-                WARN: Conanfile doesn't have 'description'.
-                It is recommended to add it as attribute""")
+                [PLUGIN - attribute_checker] pre_export(): WARN: Conanfile doesn't have 'url'. It is recommended to add it as attribute
+                [PLUGIN - attribute_checker] pre_export(): WARN: Conanfile doesn't have 'license'. It is recommended to add it as attribute
+                [PLUGIN - attribute_checker] pre_export(): WARN: Conanfile doesn't have 'description'. It is recommended to add it as attribute
+                """)
             self.assertIn(expected_output, self.client.user_io.out)
 
         if number != "Hello2":
