@@ -136,6 +136,8 @@ def log_client_rest_api_call(url, method, duration, headers):
     headers = copy.copy(headers)
     headers["Authorization"] = MASKED_FIELD
     headers["X-Client-Anonymous-Id"] = MASKED_FIELD
+    if "signature=" in url:
+        url = url.split("signature=")[0] + "signature=%s" % MASKED_FIELD
     _append_action("REST_API_CALL", {"method": method, "url": url,
                                      "duration": duration, "headers": headers})
 
